@@ -24,7 +24,7 @@ test_that("function spat.rand works", {
   expect_error(spat.rand(traits, traits, 3, "spat"))
   expect_error(spat.rand(x, traits, 3, "x"))
   expect_error(spat.rand(x[[1]], traits, 3, "spat"))
-  expect_true(ses.fd[[4]]@ptr$hasValues)
-  expect_true(ses.pd[[4]]@ptr$hasValues)
-  expect_true(ses.pd2[[4]]@ptr$hasValues)
+  expect_true(terra::hasValues(ses.fd[[4]]))
+  expect_true(terra::hasValues(ses.pd[[4]]))
+  expect_true(terra::hasValues(ses.pd2[[4]]))
   })
